<?php

namespace Drupal\graphql_compose\Controller;

use Drupal\graphql\Entity\ServerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

use Drupal\graphql\GraphQL\ResolverRegistry;

/**
 * Controller for the GraphiQL query builder IDE.
 *
 * @codeCoverageIgnore
 */
class FragmentController {

  /**
   * Controller for the GraphiQL query builder IDE.
   *
   * @param \Drupal\graphql\Entity\ServerInterface $graphql_server
   *   The server.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array
   *   The render array.
   */
  public function show(ServerInterface $graphql_server, Request $request) {

    // Settings
    $types = \Drupal::service('graphql_compose.datamanager')->getSettings('types');
    $fields = \Drupal::service('graphql_compose.datamanager')->getSettings('fields');

    // Types
    $users = \Drupal::service('graphql_compose.datamanager')->getDefinitions('user');
    $taxonomyTerms = \Drupal::service('graphql_compose.datamanager')->getDefinitions('taxonomy_term');
    if (\Drupal::moduleHandler()->moduleExists('media')) {
      $medias = \Drupal::service('graphql_compose.datamanager')->getDefinitions('media');
    } else {
      $medias = [];
    }
    if (\Drupal::moduleHandler()->moduleExists('paragraphs')) {
      $paragraphs = \Drupal::service('graphql_compose.datamanager')->getDefinitions('paragraph');
    } else {
      $paragraphs = [];
    }
    $nodes = \Drupal::service('graphql_compose.datamanager')->getDefinitions('node');

    $entities = array_merge($types, $users, $taxonomyTerms, $medias, $paragraphs, $nodes);

    foreach ($entities as $entityId => $entity) {
      foreach ($entity['fields'] as $fieldId => $field) {
        $entities[$entityId]['fields'][$fieldId]['fragment']['isFragment'] = false;
        if (in_array($field['type_sdl'], array_keys($types))) {
          $entities[$entityId]['fields'][$fieldId]['fragment']['isFragment'] = true;
          $entities[$entityId]['fields'][$fieldId]['fragment']['type_sdl'] = $types[$field['type_sdl']]['type_sdl'];
          continue;
        }
        // @TODO validate if type_sdl is any of custom detected types
        // if (in_array($field['type_sdl'], array_keys($users))) {
        //   $entities[$entityId]['fields'][$fieldId]['fragment']['isFragment'] = true;
        //   $entities[$entityId]['fields'][$fieldId]['fragment']['type_sdl'] = $users[$field['type_sdl']];
        //   continue;
        // }
      }
    }
    
    return [
      '#theme' => 'entity_fragments',
      '#entities' => $entities,
    ];
  }

}
